@@ -8,7 +8,6 @@
 typedef struct command_t
 {
 	char *command;
-	char *description;
 	int required_parameters;
 	int (*execute)(irc_t *, char **args);
 } command_t;
@@ -29,6 +28,7 @@ int cmd_set( irc_t *irc, char **args );
 int cmd_yesno( irc_t *irc, char **args );
 int cmd_identify( irc_t *irc, char **args );
 int cmd_register( irc_t *irc, char **args );
+int cmd_blist( irc_t *irc, char **cmd );
 
 extern command_t commands[];
 
